core.match_filter.detection
---------------------------

.. currentmodule:: eqcorrscan.core.match_filter.detection
.. automodule:: eqcorrscan.core.match_filter.detection

----

.. comment to end block

.. autoclass:: Detection

   .. rubric:: Methods

   .. autosummary::

      copy
      extract_stream
      write

   .. automethod:: __init__
   .. automethod:: copy
   .. automethod:: extract_stream
   .. automethod:: write

Functions
----

.. autofunction:: read_detections
.. autofunction:: write_catalog
.. autofunction:: get_catalog


.. comment to end block